/*
 * tileanimationdriver.cpp
 * Copyright 2014, Thorbjørn Lindeijer <thorbjorn@lindeijer.nl>
 *
 * This file is part of libtiled.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *
 *    2. Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE CONTRIBUTORS ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "tileanimationdriver.h"

namespace Tiled {

TileAnimationDriver::TileAnimationDriver(QObject *parent)
    : QAbstractAnimation(parent)
    , mLastTime(0)
{
    setLoopCount(-1); // loop forever
}

int TileAnimationDriver::duration() const
{
    return 1000;
}

void TileAnimationDriver::updateCurrentTime(int currentTime)
{
    int elapsed = currentTime - mLastTime;
    if (elapsed < 0)
        elapsed += 1000;

    mLastTime = currentTime;

    emit update(elapsed);
}

void TileAnimationDriver::updateState(State newState, State oldState)
{
    Q_UNUSED(oldState)

    if (newState == Stopped)
        mLastTime = 0;
}

} // namespace Tiled

#include "moc_tileanimationdriver.cpp"
